import json
import os
import sys
from reportbro import Report, ReportBroError

file_list = []


def add_files_recursive(path, level=1):
    for filename in os.listdir(path):
        full_path = os.path.join(path, filename)
        is_dir = os.path.isdir(full_path)
        file_list.append(dict(level=level, name=filename, is_dir=is_dir))
        if is_dir:
            add_files_recursive(full_path, level+1)


def print_usage(error_msg):
    print('fatal: {}\n'.format(error_msg))
    print('usage: python 09_list-files.py <dir>')


if __name__ == "__main__":
    if len(sys.argv) != 2:
        print_usage('You must specify an input directory')
        sys.exit(1)
    start_path = sys.argv[1]
    if not os.path.isdir(start_path):
        print_usage('"{}" is not a directory'.format(start_path))
        sys.exit(1)

    # prepare dynamic data for report
    add_files_recursive(start_path)
    report_data = dict(dir=start_path, files=file_list)

    # load previously saved report template
    with open('09_list-files.json', 'r') as f:
        report_definition = json.loads(f.read())
    try:
        # create report with existing template and dynamic data
        report = Report(report_definition=report_definition, data=report_data)
        report_file = report.generate_pdf()
        with open('file_list.pdf', 'wb') as f:
            f.write(report_file)
    except ReportBroError as e:
        print('error generating report:')
        print(e)
